==> haskell-simple-sendfile-0.2.27-76-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-simple-sendfile.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: simple-sendfile
version: 0.2.27
id: simple-sendfile-0.2.27-1o2bvCbMvjeBNi4x5tPODY
key: simple-sendfile-0.2.27-1o2bvCbMvjeBNi4x5tPODY
license: BSD-3-Clause
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
author: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: Cross platform library for the sendfile system call
description:
    Cross platform library for the sendfile system call.
    This library tries to call minimum system calls which
    are the bottleneck of web servers.
category: Network
abi: 013464a4e784574bbe4b7037ec8b380e
exposed: True
exposed-modules:
    Network.Sendfile System.Linux.Sendfile
hidden-modules: Network.Sendfile.Types Network.Sendfile.Linux
import-dirs: /usr/lib/ghc-8.4.3/site-local/simple-sendfile-0.2.27
library-dirs: /usr/lib/ghc-8.4.3/site-local/simple-sendfile-0.2.27
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/simple-sendfile-0.2.27
hs-libraries: HSsimple-sendfile-0.2.27-1o2bvCbMvjeBNi4x5tPODY
depends:
    base-4.11.1.0 network-2.7.0.2-1OJnZsn219R1IXngT025LR
    bytestring-0.10.8.2 unix-2.7.2.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             network-2.7.0.2-1OJnZsn219R1IXngT025LR=3133613495d02f305adaa7a6ab03f465
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             unix-2.7.2.2=f81aa481840dadf9c364a1cea96978c0
haddock-interfaces: /usr/share/doc/haskell-simple-sendfile/html/simple-sendfile.haddock
haddock-html: /usr/share/doc/haskell-simple-sendfile/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-simple-sendfile-0.2.27-78-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-simple-sendfile.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: simple-sendfile
version: 0.2.27
id: simple-sendfile-0.2.27-BOAKRtAi5h2JVp6Ng0xHlj
key: simple-sendfile-0.2.27-BOAKRtAi5h2JVp6Ng0xHlj
license: BSD-3-Clause
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
author: Kazu Yamamoto <kazu@iij.ad.jp>
synopsis: Cross platform library for the sendfile system call
description:
    Cross platform library for the sendfile system call.
    This library tries to call minimum system calls which
    are the bottleneck of web servers.
category: Network
abi: 3125944e36893ca1c5173bf6b644f008
exposed: True
exposed-modules:
    Network.Sendfile System.Linux.Sendfile
hidden-modules: Network.Sendfile.Types Network.Sendfile.Linux
import-dirs: /usr/lib/ghc-8.4.3/site-local/simple-sendfile-0.2.27
library-dirs: /usr/lib/ghc-8.4.3/site-local/simple-sendfile-0.2.27
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/simple-sendfile-0.2.27
hs-libraries: HSsimple-sendfile-0.2.27-BOAKRtAi5h2JVp6Ng0xHlj
depends:
    base-4.11.1.0 network-2.7.0.2-1OJnZsn219R1IXngT025LR
    bytestring-0.10.8.2 unix-2.7.2.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             network-2.7.0.2-1OJnZsn219R1IXngT025LR=3133613495d02f305adaa7a6ab03f465
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             unix-2.7.2.2=f81aa481840dadf9c364a1cea96978c0
haddock-interfaces: /usr/share/doc/haskell-simple-sendfile/html/simple-sendfile.haddock
haddock-html: /usr/share/doc/haskell-simple-sendfile/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
